@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 # ウィンドウインターフェイスを提供するクラス
 
-require File.expand_path File.join(File.dirname(__FILE__), 'cuscadable')
-require File.expand_path File.join(File.dirname(__FILE__), 'hierarchy_parent')
-require File.expand_path File.join(File.dirname(__FILE__), 'widget')
+require_relative 'cuscadable'
+require_relative 'hierarchy_parent'
+require_relative 'widget'
 
 class Plugin::GUI::Window
 
